==> vradi-entities-0.0.2-sources.jar: com/jurismarches/vradi/entities/FormBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class FormBean extends BusinessEntityBean implements Form {

    private static final long serialVersionUID = -1588043403L;

    public FormBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String Form$name;

     public Date Form$datePub;

     public int Form$statut;

     public Set<String> Form$thesaurus;

     public Date Form$datePeremption;

     public String Form$id;

     public Set<String> Form$sending;

 
    public void setName(String value) {
        Object oldValue = Form$name; 
        this.Form$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return Form$name;
    }


    public void setDatePub(Date value) {
        Object oldValue = Form$datePub; 
        this.Form$datePub = value;
        propertyChange.firePropertyChange("datePub", oldValue, value);
    }

    public Date getDatePub() {
        return Form$datePub;
    }


    public void setStatut(int value) {
        Object oldValue = Form$statut; 
        this.Form$statut = value;
        propertyChange.firePropertyChange("statut", oldValue, value);
    }

    public int getStatut() {
        return Form$statut;
    }

    public Set<String> getThesaurus() {
        return Form$thesaurus;
    }

    public void addThesaurus(String element) {
        Form$thesaurus.add(element);
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }
    
    public void removeThesaurus(String element) {
        Form$thesaurus.remove(element);
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }
    
    public void clearThesaurus() {
        Form$thesaurus.clear();
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }


    public void setDatePeremption(Date value) {
        Object oldValue = Form$datePeremption; 
        this.Form$datePeremption = value;
        propertyChange.firePropertyChange("datePeremption", oldValue, value);
    }

    public Date getDatePeremption() {
        return Form$datePeremption;
    }


    public void setId(String value) {
        Object oldValue = Form$id; 
        this.Form$id = value;
        propertyChange.firePropertyChange("id", oldValue, value);
    }

    public String getId() {
        return Form$id;
    }

    public Set<String> getSending() {
        return Form$sending;
    }

    public void addSending(String element) {
        Form$sending.add(element);
        propertyChange.firePropertyChange("sending", null, Form$sending);
    }
    
    public void removeSending(String element) {
        Form$sending.remove(element);
        propertyChange.firePropertyChange("sending", null, Form$sending);
    }
    
    public void clearSending() {
        Form$sending.clear();
        propertyChange.firePropertyChange("sending", null, Form$sending);
    }


} //FormBean

==> vradi-entities-0.0.3-sources.jar: com/jurismarches/vradi/entities/FormBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class FormBean extends BusinessEntityBean implements Form {

    private static final long serialVersionUID = -1986221877L;

    public FormBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String Form$name;

     public String Form$id;

     public Date Form$datePub;

     public Date Form$datePeremption;

     public Set<String> Form$thesaurus;

     public int Form$statut;

     public String Form$source;

     public String Form$description;

     public String Form$initiateur;

     public Set<String> Form$sending;

 
    public void setName(String value) {
        Object oldValue = Form$name; 
        this.Form$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return Form$name;
    }


    public void setId(String value) {
        Object oldValue = Form$id; 
        this.Form$id = value;
        propertyChange.firePropertyChange("id", oldValue, value);
    }

    public String getId() {
        return Form$id;
    }


    public void setDatePub(Date value) {
        Object oldValue = Form$datePub; 
        this.Form$datePub = value;
        propertyChange.firePropertyChange("datePub", oldValue, value);
    }

    public Date getDatePub() {
        return Form$datePub;
    }


    public void setDatePeremption(Date value) {
        Object oldValue = Form$datePeremption; 
        this.Form$datePeremption = value;
        propertyChange.firePropertyChange("datePeremption", oldValue, value);
    }

    public Date getDatePeremption() {
        return Form$datePeremption;
    }

    public Set<String> getThesaurus() {
        return Form$thesaurus;
    }

    public void addThesaurus(String element) {
        Form$thesaurus.add(element);
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }
    
    public void removeThesaurus(String element) {
        Form$thesaurus.remove(element);
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }
    
    public void clearThesaurus() {
        Form$thesaurus.clear();
        propertyChange.firePropertyChange("thesaurus", null, Form$thesaurus);
    }


    public void setStatut(int value) {
        Object oldValue = Form$statut; 
        this.Form$statut = value;
        propertyChange.firePropertyChange("statut", oldValue, value);
    }

    public int getStatut() {
        return Form$statut;
    }


    public void setSource(String value) {
        Object oldValue = Form$source; 
        this.Form$source = value;
        propertyChange.firePropertyChange("source", oldValue, value);
    }

    public String getSource() {
        return Form$source;
    }


    public void setDescription(String value) {
        Object oldValue = Form$description; 
        this.Form$description = value;
        propertyChange.firePropertyChange("description", oldValue, value);
    }

    public String getDescription() {
        return Form$description;
    }


    public void setInitiateur(String value) {
        Object oldValue = Form$initiateur; 
        this.Form$initiateur = value;
        propertyChange.firePropertyChange("initiateur", oldValue, value);
    }

    public String getInitiateur() {
        return Form$initiateur;
    }

    public Set<String> getSending() {
        return Form$sending;
    }

    public void addSending(String element) {
        Form$sending.add(element);
        propertyChange.firePropertyChange("sending", null, Form$sending);
    }
    
    public void removeSending(String element) {
        Form$sending.remove(element);
        propertyChange.firePropertyChange("sending", null, Form$sending);
    }
    
    public void clearSending() {
        Form$sending.clear();
        propertyChange.firePropertyChange("sending", null, Form$sending);
    }


} //FormBean
